TrendExt

Trait TrendExt 

pub trait TrendExt<'c> {
    type BackendError: Error;

    // Provided method
    fn github_trending(&'c self) -> TrendingBuilder<'c, Self> { ... }
}
this trait is an attempt to support multiple HTTP client backend, also we only need parameters for requesting trending information, so we use extension trait to let user requesting trending information with corresponding HTTP client directly for simplicity, we only support async HTTP client TODO: maybe this should be a sealed trait?

Required Associated Types

Provided Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'c> TrendExt<'c> for Client

Available on crate feature reqwest only.

Implementors